"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const preset = (_api, { esm = false, node = false, graphql = false, dev = process.env.NODE_NEV !== 'production', env = true, typescript = true, react = false, }) => {
    var _a;
    if (!process.env.NODE_ENV) {
        process.env.NODE_ENV = 'development';
    }
    if (!process.env.BABEL_ENV) {
        process.env.BABEL_ENV = dev ? 'development' : 'production';
    }
    if (node && react) {
        console.warn('[@vadistic/babel-preset]: using both react and node flag does not make much sense!');
    }
    if (env === true)
        env = {};
    if (typescript === true)
        typescript = {};
    if (react === true)
        react = {};
    const plugins = [
        ['@babel/plugin-proposal-decorators', { legacy: true }],
        ['@babel/plugin-proposal-class-properties', { loose: true }],
    ];
    const presets = [];
    if (typeof env === 'object') {
        const envOptions = Object.assign(Object.assign({ loose: true, modules: esm ? false : 'commonjs', shippedProposals: true }, env), { exclude: ['transform-typeof-symbol', ...(env.exclude || [])] });
        envOptions.bugfixes =
            typeof envOptions.targets === 'object' &&
                !Array.isArray(envOptions.targets) &&
                !!((_a = envOptions.targets) === null || _a === void 0 ? void 0 : _a.esmodules);
        if (process.env.NODE_ENV === 'test') {
            envOptions.modules = 'commonjs';
            envOptions.targets = { node: 'current' };
            plugins.push('babel-plugin-dynamic-import-node');
        }
        presets.push(['@babel/preset-env', envOptions]);
    }
    if (typeof typescript === 'object') {
        const typescriptOptions = {};
        presets.push(['@babel/preset-typescript', typescriptOptions]);
        if (typescript.metadata) {
            plugins.push('babel-plugin-transform-typescript-metadata');
        }
    }
    if (typeof react === 'object') {
        const reactOptions = Object.assign({ runtime: 'automatic' }, react);
        presets.push(['@babel/preset-react', reactOptions]);
    }
    if (graphql) {
        plugins.push('babel-plugin-graphql-tag');
    }
    return {
        plugins,
        presets,
    };
};
exports.default = preset;
